import java.io.OutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.PrintStream;
import java.io.BufferedWriter;
import java.util.Scanner;
import java.util.Random;
import java.io.Writer;
import java.io.OutputStreamWriter;
import java.math.BigInteger;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 *
 * @author ilyakor
 */
public class RandomWA {

  public static void main(String[] args) {
    InputStream inputStream = System.in;
    OutputStream outputStream = System.out;
    InputReader in = new InputReader(inputStream);
    OutputWriter out = new OutputWriter(outputStream);
    TaskGuessNumber solver = new TaskGuessNumber();
    solver.solve(1, in, out);
    out.close();
  }

  static class TaskGuessNumber {

    static final Random random = new Random(0xdead);

    public void solve(int testNumber, InputReader _in, OutputWriter out) {
      Scanner in = new Scanner(_in.getStream());
      int nc = in.nextInt();
      for (int it = 0; it < nc; ++it) {
        TaskGuessNumber.InteractorInterface interactor = new TaskGuessNumber.CmdlineInteractor(in);
        solve(interactor);
      }
    }

    static void solve(TaskGuessNumber.InteractorInterface interactor) {
      long val = solve(BigInteger.valueOf(10).pow(18).longValue(), 1, interactor);
      int cnt = interactor.guess(val);
      Assert.assertTrue(cnt <= 6);
    }

    static long solve(long maxn, long mult, TaskGuessNumber.InteractorInterface interactor) {
      if (maxn == 1) {
        return 1;
      }
      long x = (long) (Math.pow(maxn, 0.4)) + 1;
      long l = Math.max((long) (x * 0.8), 2);
      long r = Math.min((long) (x / 0.8), maxn);

      long val = 0, cnt = -1;
      for (int it = 0; it < 100 && cnt < 2; ++it) {
        long cur = Math.abs(random.nextLong() % (r - l + 1)) + l;
        long c = 0;
        if (cur % 2 != 0) {
          c += 1;
        }
        if (cur % 3 != 0) {
          c += 1;
        }
        if (c > cnt) {
          cnt = c;
          val = cur;
        }
      }
      Pair<Long, Long> res = interactor.ask(val * mult);
      long num = res.first, den = res.second / IntegerUtils.gcd(mult, res.second);
      if (num == 0) {
        return solve(val - 1, mult, interactor);
      }
      return den * solve(maxn / den, mult * den, interactor);
    }

    interface InteractorInterface {

      Pair<Long, Long> ask(long x);

      int guess(long x);

    }

    static class CmdlineInteractor implements TaskGuessNumber.InteractorInterface {

      Scanner in;

      public CmdlineInteractor(Scanner in) {
        this.in = in;
      }


      public Pair<Long, Long> ask(long x) {
        System.out.println("X " + x);
        System.out.flush();
        long num = in.nextLong();
        long den = in.nextLong();
        return new Pair<>(num, den);
      }


      public int guess(long x) {
        System.out.println("N " + x);
        System.out.flush();
        String s = in.next();
        return 0;
      }

    }

  }

  static class InputReader {

    private InputStream stream;

    public InputReader(InputStream stream) {
      this.stream = stream;
    }

    public InputStream getStream() {
      return stream;
    }

  }

  static class IntegerUtils {

    public static long gcd(long x, long y) {
      if (y == 0) {
        return x;
      }
      return gcd(y, x % y);
    }

  }

  static class Assert {

    public static void assertTrue(boolean flag) {
//        if (!flag)
//        while (true);
      if (!flag) {
        throw new AssertionError();
      }
    }

  }

  static class OutputWriter {

    private final PrintWriter writer;

    public OutputWriter(OutputStream outputStream) {
      writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
    }

    public OutputWriter(Writer writer) {
      this.writer = new PrintWriter(writer);
    }

    public void close() {
      writer.close();
    }

  }

  static class Pair<P, Q> {

    public P first;
    public Q second;

    public Pair() {
    }

    public Pair(P first, Q second) {
      this.first = first;
      this.second = second;
    }


    public boolean equals(Object o) {
      if (this == o) {
        return true;
      }
      if (o == null || getClass() != o.getClass()) {
        return false;
      }

      Pair pair = (Pair) o;

      if (first != null ? !first.equals(pair.first) : pair.first != null) {
        return false;
      }
      if (second != null ? !second.equals(pair.second) : pair.second != null) {
        return false;
      }

      return true;
    }


    public int hashCode() {
      int result = first != null ? first.hashCode() : 0;
      result = 31 * result + (second != null ? second.hashCode() : 0);
      return result;
    }

  }
}

